@@ -1,13 +1,11 @@
 package Text::Table::HTML;
 
-our $DATE = '2016-12-29'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.003'; # VERSION
 
-#IFUNBUILT
-# # use 5.010001;
-# # use strict;
-# # use warnings;
-#END IFUNBUILT
+use 5.010001;
+use strict;
+use warnings;
 
 sub _encode {
     state $load = do { require HTML::Entities };
@@ -89,7 +87,7 @@ Text::Table::HTML - Generate HTML table
 
 =head1 VERSION
 
-This document describes version 0.002 of Text::Table::HTML (from Perl distribution Text-Table-HTML), released on 2016-12-29.
+This document describes version 0.003 of Text::Table::HTML (from Perl distribution Text-Table-HTML), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -118,7 +116,7 @@ The example shown in the SYNOPSIS generates the following table:
  </thead>
  <tbody>
  <tr><td>alice</td><td>pvt</td><td>123&lt;456&gt;</td></tr>
- <tr><td>bob</td><td>cpl</td><td>98765321"</td></tr>
+ <tr><td>bob</td><td>cpl</td><td>98765321</td></tr>
  <tr><td>carol</td><td>brig gen</td><td>8745</td></tr>
  </tbody>
  </table>
@@ -172,7 +170,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
